"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createBIComponent = createBIComponent;

var _vue = require("vue");

function getRandId() {
  return Math.random().toString(32).slice(2);
}

function createBIComponent(_ref) {
  var RawComponent = _ref.element;
  var instance = new WeakMap();
  var id = getRandId();
  var CUSTOM_COMPONENT_CHANGE_EVENT = "CUSTOM_COMPONENT_CHANGE_EVENT_".concat(id);

  var bootstrap = function bootstrap() {};

  var mount = function mount(props) {
    if (props.container) {
      var vueInstance = (0, _vue.createApp)({
        data: function data() {
          return {
            container: props.container,
            customProps: props.customProps
          };
        },
        mounted: function mounted() {
          props.container.addEventListener(CUSTOM_COMPONENT_CHANGE_EVENT, this.handlePropsChange);
        },
        beforeUnmount: function beforeUnmount() {
          props.container.removeEventListener(CUSTOM_COMPONENT_CHANGE_EVENT, this.handlePropsChange);
        },
        methods: {
          handlePropsChange: function handlePropsChange(e) {
            if (e.detail) {
              this.customProps = e.detail;
            }
          }
        },
        render: function render() {
          return (0, _vue.h)(RawComponent, {
            container: this.container,
            customProps: this.customProps
          });
        }
      });
      vueInstance.mount(props.container);
      instance.set(props.container, vueInstance);
    }
  };

  var update = function update(props) {
    if (props.container) {
      props.container.dispatchEvent(new CustomEvent(CUSTOM_COMPONENT_CHANGE_EVENT, {
        detail: props.customProps
      }));
    }
  };

  var unmount = function unmount(props) {
    if (props.container) {
      var vueInstance = instance.get(props.container);

      if (vueInstance) {
        vueInstance.unmount();
        instance.delete(props.container);
      }
    }
  };

  return {
    bootstrap: bootstrap,
    mount: mount,
    unmount: unmount,
    update: update
  };
}